diff --git a/spring-context-indexer/src/main/java/org/springframework/context/index/processor/StandardStereotypesProvider.java b/spring-context-indexer/src/main/java/org/springframework/context/index/processor/StandardStereotypesProvider.java
index 6b36136ba6..39b8d987ce 100644
--- a/spring-context-indexer/src/main/java/org/springframework/context/index/processor/StandardStereotypesProvider.java
+++ b/spring-context-indexer/src/main/java/org/springframework/context/index/processor/StandardStereotypesProvider.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2022 the original author or authors.
+ * Copyright 2002-2023 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -25,7 +25,8 @@ import javax.lang.model.element.ElementKind;
/**
* A {@link StereotypesProvider} that extracts a stereotype for each
* {@code jakarta.*} annotation present on a class or interface.
*
* @author Stephane Nicoll
* @since 5.0
@@ -49,7 +50,7 @@ class StandardStereotypesProvider implements StereotypesProvider {
}
for (AnnotationMirror annotation : this.typeHelper.getAllAnnotationMirrors(element)) {
String type = this.typeHelper.getType(annotation);
- if (type.startsWith("jakarta.")) {
+ if (type.startsWith("jakarta.") || type.startsWith("javax.")) {
stereotypes.add(type);
}
}
@@ -25,7 +25,8 @@ import javax.lang.model.element.ElementKind;
/**
* A {@link StereotypesProvider} that extracts a stereotype for each
- * {@code jakarta.*} annotation present on a class or interface.
+ * {@code jakarta.*} or {@code javax.*} annotation present on a class or
+ * interface.
*
* @author Stephane Nicoll